# orderly-sdk-py

[![PyPI version](https://badge.fury.io/py/orderly-sdk.svg)](https://badge.fury.io/py/orderly-sdk)

Orderly.network Python SDk for EVM API(v2)

**Note: Only async Rest and Websocket APIs are maintained.**

## API docs

* NEAR API(v1): <https://docs-api.orderly.network/>
* EVM API(v2): <https://docs-api-evm.orderly.network/>
